@@ -10,6 +10,10 @@ from ._version import __version__
 from .config import LabConfig
 from .workspaces_handler import WorkspacesManager
 
+# Default workspace ID
+#  Needs to match PageConfig.defaultWorkspace define in packages/coreutils/src/pageconfig.ts
+DEFAULT_WORKSPACE = "default"
+
 
 class WorkspaceListApp(JupyterApp, LabConfig):
     version = __version__
@@ -84,7 +88,7 @@ class WorkspaceExportApp(JupyterApp, LabConfig):
             print("Too many arguments were provided for workspace export.")
             self.exit(1)
 
-        raw = self.extra_args[0]
+        raw = DEFAULT_WORKSPACE if not self.extra_args else self.extra_args[0]
         try:
             workspace = self.manager.load(raw)
             print(json.dumps(workspace))
